coef is a generic function which extracts model coefficients
from objects returned by modeling functions. coefficients is
an alias for it.
# S3 method for smle
coef(object, ...)Coefficients extracted from the model object object.
For standard model fitting classes this will be a named numeric vector.
For "maov" objects (produced by aov) it will be a matrix.
an object for which the extraction of model coefficients is meaningful.
other arguments.